==> materialfx-11.16.1.jar: module-info.java <==
module MaterialFX {
    /* transitive */ requires javafx.controls;
    /* transitive */ requires javafx.fxml;
    /* transitive */ requires javafx.graphics;
    /* transitive */ requires java.desktop;
    /* transitive */ requires mfx.core;
    /* transitive */ requires mfx.resources;
    /* transitive */ requires VirtualizedFX;

    exports io.github.palexdev.materialfx;
    exports io.github.palexdev.materialfx.beans;
    exports io.github.palexdev.materialfx.beans.properties;
    exports io.github.palexdev.materialfx.beans.properties.base;
    exports io.github.palexdev.materialfx.beans.properties.functional;
    exports io.github.palexdev.materialfx.beans.properties.resettable;
    exports io.github.palexdev.materialfx.beans.properties.styleable;
    exports io.github.palexdev.materialfx.beans.properties.synced;
    exports io.github.palexdev.materialfx.bindings;
    exports io.github.palexdev.materialfx.bindings.base;
    exports io.github.palexdev.materialfx.builders.base;
    exports io.github.palexdev.materialfx.builders.control;
    exports io.github.palexdev.materialfx.builders.layout;
    exports io.github.palexdev.materialfx.collections;
    exports io.github.palexdev.materialfx.controls;
    exports io.github.palexdev.materialfx.controls.base;
    exports io.github.palexdev.materialfx.controls.cell;
    exports io.github.palexdev.materialfx.controls.legacy;
    exports io.github.palexdev.materialfx.controls.models.spinner;
    exports io.github.palexdev.materialfx.css;
    exports io.github.palexdev.materialfx.dialogs;
    exports io.github.palexdev.materialfx.effects;
    exports io.github.palexdev.materialfx.effects.ripple;
    exports io.github.palexdev.materialfx.effects.ripple.base;
    exports io.github.palexdev.materialfx.enums;
    exports io.github.palexdev.materialfx.factories;
    exports io.github.palexdev.materialfx.filter;
    exports io.github.palexdev.materialfx.filter.base;
    exports io.github.palexdev.materialfx.i18n;
    exports io.github.palexdev.materialfx.layout;
    exports io.github.palexdev.materialfx.notifications;
    exports io.github.palexdev.materialfx.notifications.base;
    exports io.github.palexdev.materialfx.selection;
    exports io.github.palexdev.materialfx.selection.base;
    exports io.github.palexdev.materialfx.skins;
    exports io.github.palexdev.materialfx.skins.base;
    exports io.github.palexdev.materialfx.skins.legacy;
    exports io.github.palexdev.materialfx.css.themes;
    exports io.github.palexdev.materialfx.utils;
    exports io.github.palexdev.materialfx.utils.others;
    exports io.github.palexdev.materialfx.utils.others.dates;
    exports io.github.palexdev.materialfx.utils.others.loader;
    exports io.github.palexdev.materialfx.utils.others.observables;
    exports io.github.palexdev.materialfx.validation;

}

==> materialfx-11.17.0.jar: module-info.java <==
module MaterialFX {
    /* transitive */ requires javafx.controls;
    /* transitive */ requires javafx.fxml;
    /* transitive */ requires javafx.graphics;
    /* transitive */ requires java.desktop;
    /* transitive */ requires mfx.core;
    /* transitive */ requires mfx.resources;
    /* transitive */ requires VirtualizedFX;

    exports io.github.palexdev.materialfx;
    exports io.github.palexdev.materialfx.beans;
    exports io.github.palexdev.materialfx.beans.properties;
    exports io.github.palexdev.materialfx.beans.properties.base;
    exports io.github.palexdev.materialfx.beans.properties.functional;
    exports io.github.palexdev.materialfx.beans.properties.resettable;
    exports io.github.palexdev.materialfx.beans.properties.styleable;
    exports io.github.palexdev.materialfx.beans.properties.synced;
    exports io.github.palexdev.materialfx.bindings;
    exports io.github.palexdev.materialfx.bindings.base;
    exports io.github.palexdev.materialfx.builders.base;
    exports io.github.palexdev.materialfx.builders.control;
    exports io.github.palexdev.materialfx.builders.layout;
    exports io.github.palexdev.materialfx.collections;
    exports io.github.palexdev.materialfx.controls;
    exports io.github.palexdev.materialfx.controls.base;
    exports io.github.palexdev.materialfx.controls.cell;
    exports io.github.palexdev.materialfx.controls.legacy;
    exports io.github.palexdev.materialfx.controls.models.spinner;
    exports io.github.palexdev.materialfx.dialogs;
    exports io.github.palexdev.materialfx.effects;
    exports io.github.palexdev.materialfx.effects.ripple;
    exports io.github.palexdev.materialfx.effects.ripple.base;
    exports io.github.palexdev.materialfx.enums;
    exports io.github.palexdev.materialfx.factories;
    exports io.github.palexdev.materialfx.filter;
    exports io.github.palexdev.materialfx.filter.base;
    exports io.github.palexdev.materialfx.i18n;
    exports io.github.palexdev.materialfx.layout;
    exports io.github.palexdev.materialfx.notifications;
    exports io.github.palexdev.materialfx.notifications.base;
    exports io.github.palexdev.materialfx.selection;
    exports io.github.palexdev.materialfx.selection.base;
    exports io.github.palexdev.materialfx.skins;
    exports io.github.palexdev.materialfx.skins.base;
    exports io.github.palexdev.materialfx.skins.legacy;
    exports io.github.palexdev.materialfx.theming;
    exports io.github.palexdev.materialfx.theming.base;
    exports io.github.palexdev.materialfx.utils;
    exports io.github.palexdev.materialfx.utils.others;
    exports io.github.palexdev.materialfx.utils.others.dates;
    exports io.github.palexdev.materialfx.utils.others.loader;
    exports io.github.palexdev.materialfx.utils.others.observables;
    exports io.github.palexdev.materialfx.validation;

}
